MethodChannelBnotifyFlutter class
- Inheritance
-
- Object
- PlatformInterface
- BnotifyFlutterPlatform
- MethodChannelBnotifyFlutter
Constructors
Properties
- clickChannel → EventChannel
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- messageChannel → EventChannel
-
final
- methodChannel → MethodChannel
-
final
-
onClick
→ Stream<
BNotifyClick> -
no setteroverride
-
onMessage
→ Stream<
BNotifyMessage> -
no setteroverride
-
onToken
→ Stream<
String> -
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tokenChannel → EventChannel
-
final
Methods
-
initialize(
{String? configJson, bool autoNotifications = true}) → Future< void> -
override
-
logEvent(
String name) → Future< void> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
requestPermission(
) → Future< void> -
override
-
setAutoNotifications(
bool enabled) → Future< void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited